@@ -4,7 +4,7 @@ StreamFinder::Rumble - Fetch actual raw streamable URLs from Rumble.com.
 
 =head1 AUTHOR
 
-This module is Copyright (C) 2017-2023 by
+This module is Copyright (C) 2017-2024 by
 
 Jim Turner, C<< <turnerjw784 at yahoo.com> >>
 		
@@ -326,7 +326,7 @@ L<http://search.cpan.org/dist/StreamFinder-Rumble/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017-2023 Jim Turner.
+Copyright 2017-2024 Jim Turner.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
@@ -584,8 +584,6 @@ sub new
 							unless (defined $streamHash{$stream}
 									|| ($self->{'secure'} && $stream !~ /^https/o)
 									|| $class > $self->{'quality'}) {
-#$stream =~ s#hugh\.cdn\.rumble\.cloud\/video\/#sp\.rmbl\.ws\/#o;  #JWT:RANDOMLY GETTING THIS SITE THAT DOESN'T WORK?!
-print STDERR "w:Rumble converted $stream!\n"  if ($stream =~ s#hugh\.cdn\.rumble\.cloud\/video\/#sp\.rmbl\.ws\/#o);  #JWT:RANDOMLY GETTING THIS SITE THAT DOESN'T WORK?!
 								push @{$self->{'streams'}}, $stream;
 								$streamHash{$stream} = $stream;
 							}
